==> Paws-0.37.tar.gz: Paws-0.37/lib/Paws/IoT/GetIndexingConfiguration.pm <==

package Paws::IoT::GetIndexingConfiguration;
  use Moose;

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'GetIndexingConfiguration');
  class_has _api_uri  => (isa => 'Str', is => 'ro', default => '/indexing/config');
  class_has _api_method  => (isa => 'Str', is => 'ro', default => 'GET');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::IoT::GetIndexingConfigurationResponse');
1;

### main pod documentation begin ###

=head1 NAME

Paws::IoT::GetIndexingConfiguration - Arguments for method GetIndexingConfiguration on L<Paws::IoT>

=head1 DESCRIPTION

This class represents the parameters used for calling the method GetIndexingConfiguration on the
L<AWS IoT|Paws::IoT> service. Use the attributes of this class
as arguments to method GetIndexingConfiguration.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to GetIndexingConfiguration.

=head1 SYNOPSIS

    my $iot = Paws->service('IoT');
    my $GetIndexingConfigurationResponse = $iot->GetIndexingConfiguration();

    # Results:
    my $ThingIndexingConfiguration =
      $GetIndexingConfigurationResponse->ThingIndexingConfiguration;

    # Returns a L<Paws::IoT::GetIndexingConfigurationResponse> object.

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/iot/GetIndexingConfiguration>

=head1 ATTRIBUTES



=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method GetIndexingConfiguration in L<Paws::IoT>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut

==> Paws-0.44.tar.gz: Paws-0.44/lib/Paws/IoT/GetIndexingConfiguration.pm <==

package Paws::IoT::GetIndexingConfiguration;
  use Moose;

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'GetIndexingConfiguration');
  class_has _api_uri  => (isa => 'Str', is => 'ro', default => '/indexing/config');
  class_has _api_method  => (isa => 'Str', is => 'ro', default => 'GET');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::IoT::GetIndexingConfigurationResponse');
1;

### main pod documentation begin ###

=head1 NAME

Paws::IoT::GetIndexingConfiguration - Arguments for method GetIndexingConfiguration on L<Paws::IoT>

=head1 DESCRIPTION

This class represents the parameters used for calling the method GetIndexingConfiguration on the
L<AWS IoT|Paws::IoT> service. Use the attributes of this class
as arguments to method GetIndexingConfiguration.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to GetIndexingConfiguration.

=head1 SYNOPSIS

    my $iot = Paws->service('IoT');
    my $GetIndexingConfigurationResponse = $iot->GetIndexingConfiguration();

    # Results:
    my $ThingGroupIndexingConfiguration =
      $GetIndexingConfigurationResponse->ThingGroupIndexingConfiguration;
    my $ThingIndexingConfiguration =
      $GetIndexingConfigurationResponse->ThingIndexingConfiguration;

    # Returns a L<Paws::IoT::GetIndexingConfigurationResponse> object.

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/iot/GetIndexingConfiguration>

=head1 ATTRIBUTES



=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method GetIndexingConfiguration in L<Paws::IoT>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut
